Stan Math Library: stan::VectorViewMvt< T, is_array, throw_if_accessed > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | Public Member Functions | List of all members
stan::VectorViewMvt< T, is_array, throw_if_accessed > Class Template Reference

`#include <VectorViewMvt.hpp>`

## Public Types
typedef scalar_type_pre< T >::type | matrix_t

## Public Member Functions
| VectorViewMvt (matrix_t &m)
| VectorViewMvt (std::vector< matrix_t > &vm)
matrix_t & | operator[] (int i)

## Detailed Description

### template<typename T, bool is_array = stan::is_vector_like <typename stan::math::value_type<T>::type>::value, bool throw_if_accessed = false>
class stan::VectorViewMvt< T, is_array, throw_if_accessed >

Definition at line 16 of file VectorViewMvt.hpp.

## Member Typedef Documentation

template<typename T, bool is_array = stan::is_vector_like <typename stan::math::value_type<T>::type>::value, bool throw_if_accessed = false>

typedef scalar_type_pre<T>::type stan::VectorViewMvt< T, is_array, throw_if_accessed >::matrix_t

Definition at line 18 of file VectorViewMvt.hpp.

## Constructor & Destructor Documentation

template<typename T, bool is_array = stan::is_vector_like <typename stan::math::value_type<T>::type>::value, bool throw_if_accessed = false>

stan::VectorViewMvt< T, is_array, throw_if_accessed >::VectorViewMvt | ( | matrix_t & | m | ) |
| inlineexplicit

Definition at line 20 of file VectorViewMvt.hpp.

template<typename T, bool is_array = stan::is_vector_like <typename stan::math::value_type<T>::type>::value, bool throw_if_accessed = false>

stan::VectorViewMvt< T, is_array, throw_if_accessed >::VectorViewMvt | ( | std::vector< matrix_t > & | vm | ) |
| inlineexplicit

Definition at line 22 of file VectorViewMvt.hpp.

## Member Function Documentation

template<typename T, bool is_array = stan::is_vector_like <typename stan::math::value_type<T>::type>::value, bool throw_if_accessed = false>

matrix_t& stan::VectorViewMvt< T, is_array, throw_if_accessed >::operator[] | ( | int | i | ) |
| inline

Definition at line 24 of file VectorViewMvt.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/mat/meta/VectorViewMvt.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.